@@ -35,13 +35,18 @@ CmdResult cmd_userhost::Handle (const char** parameters, int pcnt, userrec *user
 
 			if (IS_OPER(u))
 			{
-				retbuf = retbuf + "*=+";
+				retbuf = retbuf + "*=";
 			}
 			else
 			{
-				retbuf = retbuf + "=+";
+				retbuf = retbuf + "=";
 			}
 
+			if (IS_AWAY(u))
+				retbuf += "-";
+			else
+				retbuf += "+";
+
 			retbuf = retbuf + u->ident + "@";
 
 			if (IS_OPER(user))
