@@ -417,10 +417,11 @@ bool DoConnect(ServerConfig* conf, const char* tag, char** entries, ValueList &v
 	int recvq = values[8].GetInteger();
 	int localmax = values[9].GetInteger();
 	int globalmax = values[10].GetInteger();
+	int port = values[11].GetInteger();
 
 	if (*allow)
 	{
-		ConnectClass c(timeout, flood, allow, pingfreq, password, threshold, sendq, recvq, localmax, globalmax);
+		ConnectClass c(timeout, flood, allow, pingfreq, password, threshold, sendq, recvq, localmax, globalmax, port);
 		conf->Classes.push_back(c);
 	}
 	else
@@ -768,7 +769,7 @@ void ServerConfig::Read(bool bail, userrec* user)
 			if (!Values[Index].validation_function(this, Values[Index].tag, Values[Index].value, vi))
 				throw CoreException("One or more values in your configuration file failed to validate. Please see your ircd.log for more information.");
 
-			switch (Values[Index].datatype)
+			switch (dt)
 			{
 				case DT_CHARPTR:
 				{
@@ -885,7 +886,7 @@ void ServerConfig::Read(bool bail, userrec* user)
 			int j = 1;
 			for (FailedPortList::iterator i = pl.begin(); i != pl.end(); i++, j++)
 			{
-				user->WriteServ("NOTICE %s :*** %d.   IP: %s     Port: %lu", user->nick, j, i->first.empty() ? "<all>" : i->first.c_str(), (unsigned long)i->second);
+				user->WriteServ("NOTICE %s :*** %d.   IP: %s     Port: %s", user->nick, j, i->first.empty() ? "<all>" : i->first.c_str(), i->second.c_str());
 			}
 		}
 
@@ -966,9 +967,6 @@ bool ServerConfig::LoadConf(ConfigDataHash &target, const char* filename, std::o
 		return false;
 	}
 
-	/* Fix the chmod of the file to restrict it to the current user and group */
-	chmod(filename,0600);
-
 	for (unsigned int t = 0; t < include_stack.size(); t++)
 	{
 		if (std::string(filename) == include_stack[t])
@@ -1505,11 +1503,13 @@ bool ServerConfig::ReadFile(file_cache &F, const char* fname)
 		std::string confpath = ServerInstance->ConfigFileName;
 		std::string newfile = fname;
 
-		if ((pos = confpath.rfind("/")) != std::string::npos)
+		if (((pos = confpath.rfind("/"))) != std::string::npos)
 			newfile = confpath.substr(0, pos) + std::string("/") + fname;
-		else if ((pos = confpath.rfind("\\")) != std::string::npos)
+		else if (((pos = confpath.rfind("\\"))) != std::string::npos)
 			newfile = confpath.substr(0, pos) + std::string("\\") + fname;
 
+		ServerInstance->Log(DEBUG, "Filename: %s", newfile.c_str());
+
 		if (!FileExists(newfile.c_str()))
 			return false;
 		file =  fopen(newfile.c_str(), "r");
@@ -1530,10 +1530,7 @@ bool ServerConfig::ReadFile(file_cache &F, const char* fname)
 			else
 				*linebuf = 0;
 
-			if (!feof(file))
-			{
-				F.push_back(*linebuf ? linebuf : " ");
-			}
+			F.push_back(*linebuf ? linebuf : " ");
 		}
 
 		fclose(file);
