@@ -639,13 +639,6 @@ InspIRCd::InspIRCd(int argc, char** argv)
 	this->BuildISupport();
 	InitializeDisabledCommands(Config->DisabledCommands, this);
 
-	if ((Config->ports.size() == 0) && (found_ports > 0))
-	{
-		printf("\nERROR: I couldn't bind any ports! Are you sure you didn't start InspIRCd twice?\n");
-		Log(DEFAULT,"ERROR: I couldn't bind any ports! Are you sure you didn't start InspIRCd twice?");
-		Exit(EXIT_STATUS_BIND);
-	}
-
 	if (Config->ports.size() != (unsigned int)found_ports)
 	{
 		printf("\nWARNING: Not all your client ports could be bound --\nstarting anyway with %d of %d client ports bound.\n\n", bounditems, found_ports);
@@ -653,9 +646,17 @@ InspIRCd::InspIRCd(int argc, char** argv)
 		int j = 1;
 		for (FailedPortList::iterator i = pl.begin(); i != pl.end(); i++, j++)
 		{
-			printf("%d.\tIP: %s\tPort: %lu\n", j, i->first.empty() ? "<all>" : i->first.c_str(), (unsigned long)i->second);
+			printf("%d.\tAddress: %s\tReason: %s\n", j, i->first.empty() ? "<all>" : i->first.c_str(), i->second.c_str());
 		}
 	}
+
+	if ((Config->ports.size() == 0) && (found_ports > 0))
+	{
+		printf("\nERROR: I couldn't bind any ports! Are you sure you didn't start InspIRCd twice?\n");
+		Log(DEFAULT,"ERROR: I couldn't bind any ports! Are you sure you didn't start InspIRCd twice?");
+		Exit(EXIT_STATUS_BIND);
+	}
+
 #ifndef WINDOWS
 	if (!Config->nofork)
 	{
@@ -704,11 +705,11 @@ std::string InspIRCd::GetVersionString()
 
 	if (*Config->CustomVersion)
 	{
-		snprintf(versiondata,MAXBUF,"%s %s :%s",VERSION,Config->ServerName,Config->CustomVersion);
+		snprintf(versiondata,MAXBUF,"InspIRCd-1.1 %s :%s",Config->ServerName,Config->CustomVersion);
 	}
 	else
 	{
-		snprintf(versiondata,MAXBUF,"%s %s :%s [FLAGS=%s,%s,%s]",VERSION,Config->ServerName,SYSTEM,REVISION,SE->GetName().c_str(),dnsengine);
+		snprintf(versiondata,MAXBUF,"InspIRCd-1.1 %s :%s (%s) [FLAGS=%s,%s,%s]",Config->ServerName,SYSTEM,VERSION,REVISION,SE->GetName().c_str(),dnsengine);
 	}
 	return versiondata;
 }
@@ -1191,8 +1192,7 @@ bool InspIRCd::AllModulesReportReady(userrec* user)
 	{
 		if (Config->implement_lists[i][I_OnCheckReady])
 		{
-			int res = modules[i]->OnCheckReady(user);
-			if (!res)
+			if (!modules[i]->OnCheckReady(user))
 				return false;
 		}
 	}
