@@ -148,6 +148,9 @@ class ModuleSSLOpenSSL : public Module
 		ctx = SSL_CTX_new( SSLv23_server_method() );
 		clictx = SSL_CTX_new( SSLv23_client_method() );
 
+		SSL_CTX_set_mode(ctx, SSL_MODE_ENABLE_PARTIAL_WRITE | SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER);
+		SSL_CTX_set_mode(clictx, SSL_MODE_ENABLE_PARTIAL_WRITE | SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER);
+
 		SSL_CTX_set_verify(ctx, SSL_VERIFY_PEER | SSL_VERIFY_CLIENT_ONCE, OnVerify);
 		SSL_CTX_set_verify(clictx, SSL_VERIFY_PEER | SSL_VERIFY_CLIENT_ONCE, OnVerify);
 
@@ -303,6 +306,7 @@ class ModuleSSLOpenSSL : public Module
 	{
 		SSL_CTX_free(ctx);
 		SSL_CTX_free(clictx);
+		ServerInstance->UnpublishInterface("InspSocketHook", this);
 	}
 
 	virtual void OnCleanup(int target_type, void* item)
@@ -524,7 +528,7 @@ class ModuleSSLOpenSSL : public Module
 					{
 						memcpy(buffer, session->inbuf, count);
 						// Move the stuff left in inbuf to the beginning of it
-						memcpy(session->inbuf, session->inbuf + count, (session->inbufoffset - count));
+						memmove(session->inbuf, session->inbuf + count, (session->inbufoffset - count));
 						// Now we need to set session->inbufoffset to the amount of data still waiting to be handed to insp.
 						session->inbufoffset -= count;
 						// Insp uses readresult as the count of how much data there is in buffer, so:
