@@ -225,13 +225,13 @@ void TreeSocket::OnError(InspSocketError e)
 				Utils->DoFailOver(MyLink);
 		break;
 		case I_ERR_SOCKET:
-			Utils->Creator->RemoteMessage(NULL,"Connection failed: Could not create socket");
+			Utils->Creator->RemoteMessage(NULL,"Connection failed: Could not create socket (%s)", strerror(errno));
 		break;
 		case I_ERR_BIND:
-			Utils->Creator->RemoteMessage(NULL,"Connection failed: Error binding socket to address or port");
+			Utils->Creator->RemoteMessage(NULL,"Connection failed: Error binding socket to address or port (%s)", strerror(errno));
 		break;
 		case I_ERR_WRITE:
-			Utils->Creator->RemoteMessage(NULL,"Connection failed: I/O error on connection");
+			Utils->Creator->RemoteMessage(NULL,"Connection failed: I/O error on connection (%s)", strerror(errno));
 		break;
 		case I_ERR_NOMOREFDS:
 			Utils->Creator->RemoteMessage(NULL,"Connection failed: Operating system is out of file descriptors!");
@@ -413,7 +413,7 @@ void TreeSocket::SendError(const std::string &errormessage)
 {
 	/* Display the error locally as well as sending it remotely */
 	this->WriteLine("ERROR :"+errormessage);
-	Utils->Creator->RemoteMessage(NULL, "Sent \2ERROR\2 to %s: %s", (this->InboundServerName.empty() ? "<unknown>" : this->InboundServerName.c_str()), errormessage.c_str());
+	Utils->Creator->RemoteMessage(NULL, "Sent \2ERROR\2 to %s: %s", (this->InboundServerName.empty() ? this->GetIP().c_str() : this->InboundServerName.c_str()), errormessage.c_str());
 	/* One last attempt to make sure the error reaches its target */
 	this->FlushWriteBuffer();
 }
@@ -503,6 +503,7 @@ bool TreeSocket::Capab(const std::deque<std::string> &params)
 			this->SetTheirChallenge(n->second);
 			if (!this->GetTheirChallenge().empty() && (this->LinkState == CONNECTING))
 			{
+				this->SendCapabilities();
 				this->WriteLine(std::string("SERVER ")+this->Instance->Config->ServerName+" "+this->MakePass(OutboundPass, this->GetTheirChallenge())+" 0 :"+this->Instance->Config->ServerDesc);
 			}
 		}
@@ -510,7 +511,10 @@ bool TreeSocket::Capab(const std::deque<std::string> &params)
 		{
 			/* They didnt specify a challenge or we don't have m_sha256.so, we use plaintext */
 			if (this->LinkState == CONNECTING)
+			{
+				this->SendCapabilities();
 				this->WriteLine(std::string("SERVER ")+this->Instance->Config->ServerName+" "+OutboundPass+" 0 :"+this->Instance->Config->ServerDesc);
+			}
 		}
 
 		if (reason.length())
@@ -724,17 +728,13 @@ bool TreeSocket::ForceTopic(const std::string &source, std::deque<std::string> &
 	{
 		if ((ts >= c->topicset) || (!*c->topic))
 		{
-			std::string oldtopic = c->topic;
-			strlcpy(c->topic,params[3].c_str(),MAXTOPIC);
-			strlcpy(c->setby,params[2].c_str(),127);
-			c->topicset = ts;
-			/* if the topic text is the same as the current topic,
-			 * dont bother to send the TOPIC command out, just silently
-			 * update the set time and set nick.
-			 */
-			if (oldtopic != params[3])
+			userrec* user = this->Instance->FindNick(source);
+
+			if (c->topic != params[3])
 			{
-				userrec* user = this->Instance->FindNick(source);
+				// Update topic only when it differs from current topic
+				strlcpy(c->topic, params[3].c_str(), MAXTOPIC);
+
 				if (!user)
 				{
 					c->WriteChannelWithServ(Instance->Config->ServerName, "TOPIC %s :%s", c->name, c->topic);
@@ -742,10 +742,27 @@ bool TreeSocket::ForceTopic(const std::string &source, std::deque<std::string> &
 				else
 				{
 					c->WriteChannel(user, "TOPIC %s :%s", c->name, c->topic);
-					nsource = user->server;
 				}
 			}
 
+			// But always update set time and setter
+			strlcpy(c->setby, params[2].c_str(), 127);
+			c->topicset = ts;
+
+			/*
+			 * Take careful note of what happens here;
+			 * Above, we display the topic change to the server IF the topic incoming is different to the topic already set.
+			 * HERE, we find the server the user that sent this topic is on, so we *do not* send topics back to the link they just
+			 * came from. This *cannot* be easily merged with the above check!
+			 *
+			 * Thanks to Anope and Namegduf for finally helping me isolate this
+			 *			-- w00t (5th/aug/2008)
+			 */
+			if (user)
+			{
+				nsource = user->server;
+			}
+
 			/* all done, send it on its way */
 			params[3] = ":" + params[3];
 			Utils->DoOneToAllButSender(source,"FTOPIC",params,nsource);
@@ -915,8 +932,9 @@ bool TreeSocket::IntroduceClient(const std::string &source, std::deque<std::stri
 	 */
 	if (params.size() != 8)
 	{
-		this->WriteLine(std::string(":")+this->Instance->Config->ServerName+" KILL "+params[1]+" :Invalid client introduction ("+params[1]+"?)");
-		return true;
+		if (params.size() >= 2)
+			this->WriteLine(std::string(":")+this->Instance->Config->ServerName+" KILL "+params[1]+" :Invalid client introduction ("+params[1]+"?)");
+				return true;
 	}
 
 	time_t age = ConvToInt(params[0]);
@@ -1027,7 +1045,6 @@ bool TreeSocket::IntroduceClient(const std::string &source, std::deque<std::stri
  */
 void TreeSocket::SendFJoins(TreeServer* Current, chanrec* c)
 {
-	std::string buffer;
 	char list[MAXBUF];
 	std::string individual_halfops = std::string(":")+this->Instance->Config->ServerName+" FMODE "+c->name+" "+ConvToStr(c->age);
 
@@ -1052,7 +1069,7 @@ void TreeSocket::SendFJoins(TreeServer* Current, chanrec* c)
 
 		if (curlen > (480-NICKMAX))
 		{
-			buffer.append(list).append("\r\n");
+			this->WriteLine(list);
 			dlen = curlen = snprintf(list,MAXBUF,":%s FJOIN %s %lu",this->Instance->Config->ServerName,c->name,(unsigned long)c->age);
 			ptr = list + dlen;
 			ptrlen = 0;
@@ -1061,9 +1078,10 @@ void TreeSocket::SendFJoins(TreeServer* Current, chanrec* c)
 	}
 
 	if (numusers)
-		buffer.append(list).append("\r\n");
+		this->WriteLine(list);
 
-	buffer.append(":").append(this->Instance->Config->ServerName).append(" FMODE ").append(c->name).append(" ").append(ConvToStr(c->age)).append(" +").append(c->ChanModes(true)).append("\r\n");
+	snprintf(list, MAXBUF, ":%s FMODE %s %lu +%s", this->Instance->Config->ServerName, c->name, (unsigned long)c->age, c->ChanModes(true));
+	this->WriteLine(list);
 
 	int linesize = 1;
 	for (BanList::iterator b = c->bans.begin(); b != c->bans.end(); b++)
@@ -1079,7 +1097,8 @@ void TreeSocket::SendFJoins(TreeServer* Current, chanrec* c)
 		if ((params.length() >= MAXMODES) || (currsize > 350))
 		{
 			/* Wrap at MAXMODES */
-			buffer.append(":").append(this->Instance->Config->ServerName).append(" FMODE ").append(c->name).append(" ").append(ConvToStr(c->age)).append(" +").append(modes).append(params).append("\r\n");
+			snprintf(list, MAXBUF, ":%s FMODE %s %lu +%s%s", this->Instance->Config->ServerName, c->name, (unsigned long)c->age, modes.c_str(), params.c_str());
+			this->WriteLine(list);
 			modes.clear();
 			params.clear();
 			linesize = 1;
@@ -1088,9 +1107,11 @@ void TreeSocket::SendFJoins(TreeServer* Current, chanrec* c)
 
 	/* Only send these if there are any */
 	if (!modes.empty())
-		buffer.append(":").append(this->Instance->Config->ServerName).append(" FMODE ").append(c->name).append(" ").append(ConvToStr(c->age)).append(" +").append(modes).append(params);
+	{
+		snprintf(list, MAXBUF, ":%s FMODE %s %lu +%s%s", this->Instance->Config->ServerName, c->name, (unsigned long)c->age, modes.c_str(), params.c_str());
+		this->WriteLine(list);
 
-	this->WriteLine(buffer);
+	}
 }
 
 /** Send G, Q, Z and E lines */
