@@ -36,11 +36,11 @@
 
 static std::map<std::string, std::string> warned;       /* Server names that have had protocol violation warnings displayed for them */
 
-int TreeSocket::WriteLine(std::string line)
+void TreeSocket::WriteLine(std::string line)
 {
 	Instance->Log(DEBUG, "S[%d] -> %s", this->GetFd(), line.c_str());
 	line.append("\r\n");
-	return this->Write(line);
+	this->Write(line);
 }
 
 
@@ -94,16 +94,16 @@ bool TreeSocket::Modules(const std::string &prefix, std::deque<std::string> &par
 		strlcpy(modulename,Instance->Config->module_names[i].c_str(),256);
 		if (*source->oper)
 		{
-			snprintf(strbuf, MAXBUF, "::%s 900 %s :0x%08lx %d.%d.%d.%d %s (%s)",Instance->Config->ServerName,source->nick,(long unsigned int)Instance->modules[i],V.Major,V.Minor,V.Revision,V.Build,ServerConfig::CleanFilename(modulename),flagstate+2);
+			snprintf(strbuf, MAXBUF, "::%s 702 %s :0x%08lx %d.%d.%d.%d %s (%s)",Instance->Config->ServerName,source->nick,(long unsigned int)Instance->modules[i],V.Major,V.Minor,V.Revision,V.Build,ServerConfig::CleanFilename(modulename),flagstate+2);
 		}
 		else
 		{
-			snprintf(strbuf, MAXBUF, "::%s 900 %s :%s",Instance->Config->ServerName,source->nick,ServerConfig::CleanFilename(modulename));
+			snprintf(strbuf, MAXBUF, "::%s 702 %s :%s",Instance->Config->ServerName,source->nick,ServerConfig::CleanFilename(modulename));
 		}
 		par[1] = strbuf;
 		Utils->DoOneToOne(Instance->Config->ServerName, "PUSH", par, source->server);
 	}
-	snprintf(strbuf, MAXBUF, "::%s 901 %s :End of MODULES list", Instance->Config->ServerName, source->nick);
+	snprintf(strbuf, MAXBUF, "::%s 703 %s :End of MODULES list", Instance->Config->ServerName, source->nick);
 	par[1] = strbuf;
 	Utils->DoOneToOne(Instance->Config->ServerName, "PUSH", par, source->server);
 	return true;
@@ -344,12 +344,19 @@ bool TreeSocket::RemoteRehash(const std::string &prefix, std::deque<std::string>
 		return false;
 
 	std::string servermask = params[0];
+	std::string parameter;
+
+	if (params.size() > 1)
+	{
+		parameter = params[1];
+	}
 
 	if (this->Instance->MatchText(this->Instance->Config->ServerName,servermask))
 	{
 		this->Instance->SNO->WriteToSnoMask('l',"Remote rehash initiated by \002"+prefix+"\002.");
 		this->Instance->RehashServer();
 		Utils->ReadConfiguration(true);
+		FOREACH_MOD_I(this->Instance, I_OnRehash, OnRehash(NULL, parameter));
 		InitializeDisabledCommands(Instance->Config->DisabledCommands, Instance);
 	}
 	Utils->DoOneToAllButSender(prefix,"REHASH",params,prefix);
@@ -365,10 +372,10 @@ bool TreeSocket::RemoteKill(const std::string &prefix, std::deque<std::string> &
 
 	if (who)
 	{
-		/* Prepend kill source, if we don't have one */ 	 
-		if (*(params[1].c_str()) != '[')
+		/* Prepend kill source, if we don't have one -- '[' is check for older 1.1 servers, and services, that prefix reason with servername. */
+		if ((*(params[1].c_str()) != 'K') && (*(params[1].c_str()) != '['))
 		{
-			params[1] = "[" + prefix + "] Killed (" + params[1] +")";
+			params[1] = "Killed (" + params[1] +")";
 		}
 		std::string reason = params[1];
 		params[1] = ":" + params[1];
@@ -936,6 +943,7 @@ bool TreeSocket::Inbound_Server(std::deque<std::string> &params)
 
 			// this is good. Send our details: Our server name and description and hopcount of 0,
 			// along with the sendpass from this block.
+			this->SendCapabilities();
 			this->WriteLine(std::string("SERVER ")+this->Instance->Config->ServerName+" "+this->MakePass(x->SendPass, this->GetTheirChallenge())+" 0 :"+this->Instance->Config->ServerDesc);
 			// move to the next state, we are now waiting for THEM.
 			this->LinkState = WAIT_AUTH_2;
@@ -1587,7 +1595,7 @@ int TreeSocket::OnIncomingConnection(int newsock, char* ip)
 
 		if (!found)
 		{
-			Utils->Creator->RemoteMessage(NULL,"Server connection from %s denied (no link blocks with that IP address)", ip);
+			this->Instance->SNO->WriteToSnoMask('d',"Server connection from %s denied (no link blocks with that IP address", ip);
 			close(newsock);
 			return false;
 		}
