@@ -218,6 +218,7 @@ void UserResolver::OnLookupComplete(const std::string &result, unsigned int ttl,
 					strlcpy(this->bound_user->host, hostname.c_str(),64);
 					/* Invalidate cache */
 					this->bound_user->InvalidateCache();
+					ServerInstance->next_call = ServerInstance->Time();
 				}
 			}
 			else
@@ -328,7 +329,7 @@ userrec::userrec(InspIRCd* Instance) : ServerInstance(Instance)
 	age = ServerInstance->Time(true);
 	lines_in = lastping = signon = idle_lastmsg = nping = registered = 0;
 	ChannelCount = timeout = flood = bytes_in = bytes_out = cmds_in = cmds_out = 0;
-	quitting = exempt = haspassed = dns_done = false;
+	silentquit = quitting = exempt = haspassed = dns_done = false;
 	fd = -1;
 	recvq.clear();
 	sendq.clear();
@@ -431,8 +432,11 @@ char* userrec::MakeHostIP()
 
 void userrec::CloseSocket()
 {
-	shutdown(this->fd,2);
-	close(this->fd);
+	if (this->fd > -1)
+	{
+		shutdown(this->fd,2);
+		close(this->fd);
+	}
 }
 
 char* userrec::GetFullHost()
@@ -525,6 +529,13 @@ InvitedList* userrec::GetInviteList()
 
 void userrec::InviteTo(const irc::string &channel)
 {
+	for (InvitedList::iterator i = invites.begin(); i != invites.end(); i++)
+	{
+		if (channel == *i)
+		{
+			return;
+		}
+	}
 	invites.push_back(channel);
 }
 
@@ -919,7 +930,7 @@ void userrec::AddClient(InspIRCd* Instance, int socket, int port, bool iscached,
 	 * Check connect class settings and initialise settings into userrec.
 	 * This will be done again after DNS resolution. -- w00t
 	 */
-	New->CheckClass();
+	New->CheckClass(i);
 
 	Instance->local_users.push_back(New);
 
@@ -998,10 +1009,8 @@ unsigned long userrec::LocalCloneCount()
 /*
  * Check class restrictions
  */
-void userrec::CheckClass()
+void userrec::CheckClass(ConnectClass *a)
 {
-	ConnectClass* a = this->GetClass();
-
 	if ((!a) || (a->GetType() == CC_DENY))
 	{
 		userrec::QuitUser(ServerInstance, this, "Unauthorised connection");
@@ -1034,13 +1043,29 @@ void userrec::FullConnect()
 	ServerInstance->stats->statsConnects++;
 	this->idle_lastmsg = ServerInstance->Time();
 
+
+	ConnectClass *a = this->GetClass();
+	if (!a)
+	{
+		/*
+		 * This can happen:
+		 *  - user connects
+		 *  - /rehash, removing <connect> tag they matched
+		 *  - dns completes (putting us here) ...but they no longer have a connect tag
+		 * Catch it here. Thanks Szymek!
+		 *  -- w00t
+		 */
+		userrec::QuitUser(ServerInstance, this, "Invalid password");
+		return;
+	}
+	
 	/*
 	 * You may be thinking "wtf, we checked this in userrec::AddClient!" - and yes, we did, BUT.
 	 * At the time AddClient is called, we don't have a resolved host, by here we probably do - which
 	 * may put the user into a totally seperate class with different restrictions! so we *must* check again.
 	 * Don't remove this! -- w00t
 	 */
-	this->CheckClass();
+	this->CheckClass(a);
 	
 	/* Check the password, if one is required by the user's connect class.
 	 * This CANNOT be in CheckClass(), because that is called prior to PASS as well!
@@ -1071,7 +1096,7 @@ void userrec::FullConnect()
 		{
 			char reason[MAXBUF];
 			if (*ServerInstance->Config->MoronBanner)
-				this->WriteServ("NOTICE %s :*** %s", this, ServerInstance->Config->MoronBanner);
+				this->WriteServ("NOTICE %s :*** %s", this->nick, ServerInstance->Config->MoronBanner);
 			snprintf(reason,MAXBUF,"K-Lined: %s",n->reason);
 			userrec::QuitUser(ServerInstance, this, reason);
 			return;
@@ -1080,9 +1105,9 @@ void userrec::FullConnect()
 
 	this->WriteServ("NOTICE Auth :Welcome to \002%s\002!",ServerInstance->Config->Network);
 	this->WriteServ("001 %s :Welcome to the %s IRC Network %s!%s@%s",this->nick, ServerInstance->Config->Network, this->nick, this->ident, this->host);
-	this->WriteServ("002 %s :Your host is %s, running version %s",this->nick,ServerInstance->Config->ServerName,VERSION);
+	this->WriteServ("002 %s :Your host is %s, running version InspIRCd-1.1",this->nick,ServerInstance->Config->ServerName);
 	this->WriteServ("003 %s :This server was created %s %s", this->nick, __TIME__, __DATE__);
-	this->WriteServ("004 %s %s %s %s %s %s", this->nick, ServerInstance->Config->ServerName, VERSION, ServerInstance->Modes->UserModeList().c_str(), ServerInstance->Modes->ChannelModeList().c_str(), ServerInstance->Modes->ParaModeList().c_str());
+	this->WriteServ("004 %s %s InspIRCd-1.1 %s %s %s", this->nick, ServerInstance->Config->ServerName, ServerInstance->Modes->UserModeList().c_str(), ServerInstance->Modes->ChannelModeList().c_str(), ServerInstance->Modes->ParaModeList().c_str());
 
 	ServerInstance->Config->Send005(this);
 
@@ -1615,9 +1640,6 @@ void userrec::WriteCommonExcept(const std::string &text)
 
 void userrec::WriteWallOps(const std::string &text)
 {
-	if (!IS_OPER(this) && IS_LOCAL(this))
-		return;
-
 	std::string wallop("WALLOPS :");
 	wallop.append(text);
 
