@@ -1,12 +1,12 @@
-/*       +------------------------------------+
- *       | Inspire Internet Relay Chat Daemon |
- *       +------------------------------------+
+/*	   +------------------------------------+
+ *	   | Inspire Internet Relay Chat Daemon |
+ *	   +------------------------------------+
  *
  *  InspIRCd: (C) 2002-2008 InspIRCd Development Team
  * See: http://www.inspircd.org/wiki/index.php/Credits
  *
  * This program is free but copyrighted software; see
- *            the file COPYING for details.
+ *			the file COPYING for details.
  *
  * ---------------------------------------------------
  */
@@ -81,7 +81,7 @@ bool escape_string(char * str, size_t size)
 {
 	size_t len = strlen(str);
 	char * d_str = (char*)malloc(len * 2);
-    
+	
 	size_t i = 0;
 	size_t j = 0;
 
@@ -100,7 +100,7 @@ bool escape_string(char * str, size_t size)
 
 	d_str[j++] = 0;
 
-    if(j > size)
+	if(j > size)
 	{
 		free(d_str);
 		return false;
@@ -122,23 +122,18 @@ int get_svn_revision(char * buffer, size_t len)
 	7033
 	*/
 	char buf[1000];
+	int rev = 0;
 	FILE * f = fopen("..\\.svn\\entries", "r");
-	if(!f) goto bad_rev;
-    
-	if(!fgets(buf, 1000, f)) goto bad_rev;
-	if(!fgets(buf, 1000, f)) goto bad_rev;
-	if(!fgets(buf, 1000, f)) goto bad_rev;
-	if(!fgets(buf, 1000, f)) goto bad_rev;
-	int rev = atoi(buf);
-	if(rev == 0) goto bad_rev;
-	sprintf(buffer, "%u", rev);
-	fclose(f);
+	if (f)
+	{
+		for (int q = 0; q < 4; ++q)
+			fgets(buf, 1000, f);
+
+		rev = atoi(buf);
+		sprintf(buffer, "%u", rev);
+		fclose(f);
+	}
 	return rev;
-	
-bad_rev:
-	strcpy(buffer, "non-svn");
-	if(f) fclose(f);
-	return 0;
 }
 
 int __stdcall WinMain(IN HINSTANCE hInstance, IN HINSTANCE hPrevInstance, IN LPSTR lpCmdLine, IN int nShowCmd )
@@ -172,8 +167,8 @@ void Banner()
 {
 	printf_c("\nWelcome to the \033[1mInspIRCd\033[0m Configuration program! (\033[1minteractive mode\033[0m)\n"
 			 "\033[1mPackage maintainers: Type ./configure --help for non-interactive help\033[0m\n\n");
-	printf_c("*** If you are unsure of any of these values, leave it blank for    ***\n"
-			 "*** standard settings that will work, and your server will run      ***\n"
+	printf_c("*** If you are unsure of any of these values, leave it blank for	***\n"
+			 "*** standard settings that will work, and your server will run	  ***\n"
 			 "*** using them. Please consult your IRC network admin if in doubt.  ***\n\n"
 			 "Press \033[1m<RETURN>\033[0m to accept the default for any option, or enter\n"
 			 "a new value. Please note: You will \033[1mHAVE\033[0m to read the docs\n"
@@ -202,6 +197,7 @@ void Run()
 	int topiclen = 500;
 	int kicklen = 255;
 	int rllen = 128;
+	bool ipv6 = false;
 	int awaylen = 200;
 	int revision = get_svn_revision(revision_text, MAX_PATH);
 	char version[514];
@@ -232,20 +228,24 @@ void Run()
 #endif
 	printf_c("InspIRCd revision ID: \033[1;32m%s \033[0m\n\n", revision ? revision_text : "(Non-SVN build)");
 
-	max_fd = get_int_option("What is the maximum file descriptor count you would like to allow?", 1024);
+	max_fd = get_int_option("What is the maximum file descriptor count you would like to allow?", 10240);
 
 	// detect windows
 	if(iswinxp())
 	{
 		printf_c("You are running Windows 2000 or above, and IOCP support is most likely available.\n"
-			     "This removes the socket number limitation of select and is much more efficent.\n"
-				 "If you are unsure, answer yes.\n\n");
+		"This removes the socket number limitation of select and is much more efficent.\n"
+		"If you are unsure, answer no. (You SHOULD NOT be using this, as it MAY not work!)\n\n");
 
-		use_iocp = get_bool_option("Do you want to use the IOCP implementation?", true);
+		use_iocp = get_bool_option("Do you want to use the IOCP implementation?", false);
 	}
 
-	support_ip6links = get_bool_option("\nYou have chosen to build an \033[1;32mIPV4-only\033[0m server.\nWould you like to enable support for linking to IPV6-enabled InspIRCd servers?\nIf you are using a recent operating system and are unsure, answer yes.\nIf you answer 'no' here, your InspIRCd server will be unable\nto parse IPV6 addresses (e.g. for CIDR bans)", 
-		true);
+	ipv6 = get_bool_option("Would you like to enable IPV6?", false);
+
+	if (!ipv6)
+		support_ip6links = get_bool_option("\nYou have chosen to build an \033[1;32mIPV4-only\033[0m server.\nWould you like to enable support for linking to IPV6-enabled InspIRCd servers?\nIf you are using a recent operating system and are unsure, answer yes.\nIf you answer 'no' here, your InspIRCd server will be unable\nto parse IPV6 addresses (e.g. for CIDR bans)", true);
+	else
+		support_ip6links = true;
 	
 	printf_c("\033[1mAll paths are relative to the binary directory.\033[0m\n");
 	get_string_option("In what directory do you wish to install the InspIRCd base?", "..", base_path);
@@ -262,8 +262,8 @@ void Run()
 		"of the 'maximum number of clients' setting which may be different on\n"
 		"different servers on the network.\n\n");
 
-    
-	max_clients = get_int_option("Please enter the maximum number of clients at any one time?", 1024);
+	
+	max_clients = get_int_option("Please enter the maximum number of clients at any one time?", 10240);
 	nicklen = get_int_option("Please enter the maximum length of nicknames?", 31);
 	chanlen = get_int_option("Please enter the maximum length of channel names?", 64);
 	modechanges = get_int_option("Please enter the maximum number of mode changes in one line?", 20);
@@ -277,22 +277,22 @@ void Run()
 	printf_c("\n\033[1;32mPre-build configuration is complete!\n\n");	sc(TNORMAL);
 
 	// dump all the options back out
-	printf_c("\033[0mBase install path:\033[1;32m        %s\n", base_path);
-	printf_c("\033[0mConfig path:\033[1;32m              %s\n", config_file);
-	printf_c("\033[0mModule path:\033[1;32m              %s\n", mod_path);
-	printf_c("\033[0mLibrary path:\033[1;32m             %s\n", library_dir);
-	printf_c("\033[0mSocket Engine:\033[1;32m            %s\n", use_iocp ? "iocp" : "select");
-	printf_c("\033[0mMax file descriptors:\033[1;32m     %u\n", max_fd);
-	printf_c("\033[0mMax connections:\033[1;32m          %u\n", max_clients);
-	printf_c("\033[0mMax nickname length:\033[1;32m      %u\n", nicklen);
-	printf_c("\033[0mMax channel length:\033[1;32m       %u\n", chanlen);
-	printf_c("\033[0mMax mode length:\033[1;32m          %u\n", modechanges);
-	printf_c("\033[0mMax ident length:\033[1;32m         %u\n", identlen);
-	printf_c("\033[0mMax quit length:\033[1;32m          %u\n", quitlen);
-	printf_c("\033[0mMax topic length:\033[1;32m         %u\n", topiclen);
-	printf_c("\033[0mMax kick length:\033[1;32m          %u\n", kicklen);
-	printf_c("\033[0mMax name length:\033[1;32m          %u\n", rllen);
-	printf_c("\033[0mMax away length:\033[1;32m          %u\n", awaylen);
+	printf_c("\033[0mBase install path:\033[1;32m		%s\n", base_path);
+	printf_c("\033[0mConfig path:\033[1;32m			  %s\n", config_file);
+	printf_c("\033[0mModule path:\033[1;32m			  %s\n", mod_path);
+	printf_c("\033[0mLibrary path:\033[1;32m			 %s\n", library_dir);
+	printf_c("\033[0mSocket Engine:\033[1;32m			%s\n", use_iocp ? "iocp" : "select");
+	printf_c("\033[0mMax file descriptors:\033[1;32m	 %u\n", max_fd);
+	printf_c("\033[0mMax connections:\033[1;32m		  %u\n", max_clients);
+	printf_c("\033[0mMax nickname length:\033[1;32m	  %u\n", nicklen);
+	printf_c("\033[0mMax channel length:\033[1;32m	   %u\n", chanlen);
+	printf_c("\033[0mMax mode length:\033[1;32m		  %u\n", modechanges);
+	printf_c("\033[0mMax ident length:\033[1;32m		 %u\n", identlen);
+	printf_c("\033[0mMax quit length:\033[1;32m		  %u\n", quitlen);
+	printf_c("\033[0mMax topic length:\033[1;32m		 %u\n", topiclen);
+	printf_c("\033[0mMax kick length:\033[1;32m		  %u\n", kicklen);
+	printf_c("\033[0mMax name length:\033[1;32m		  %u\n", rllen);
+	printf_c("\033[0mMax away length:\033[1;32m		  %u\n", awaylen);
 	printf("\n"); sc(TNORMAL);
 	if(get_bool_option("Are these settings correct?", true) == false)
 	{
@@ -313,7 +313,8 @@ void Run()
 	fprintf(f, "#define __CONFIGURATION_AUTO__\n\n");
 	if(use_iocp)
 		fprintf(f, "#define CONFIG_USE_IOCP 1\n\n");
-
+	if (ipv6)
+		fprintf(f, "#define IPV6 1\n\n");
 	fprintf(f, "#define CONFIG_FILE \"%s/inspircd.conf\"\n", config_file);
 	fprintf(f, "#define MOD_PATH \"%s\"\n", mod_path);
 	fprintf(f, "#define MAX_DESCRIPTORS %u\n", max_fd);
@@ -385,12 +386,12 @@ void WriteCompileCommands()
 		{
 			strcpy(commands[command_count], fd.cFileName);
 			commands[command_count][strlen(fd.cFileName) - 4] = 0;
-			printf("    %s\n", commands[command_count]);
+			printf("	%s\n", commands[command_count]);
 			++command_count;
 		} while(FindNextFile(fh, &fd));
 		sc(TNORMAL);
 	}
-    
+	
 	// Write our spiffy new makefile :D
 	// I am such a lazy fucker :P
 	FILE * f = fopen("..\\src\\commands.mak", "w");
@@ -407,13 +408,13 @@ void WriteCompileCommands()
 #ifdef WIN64
 	// /MACHINE:X64
 	#ifdef _DEBUG
-		fprintf(f, "  cl /nologo /LD /Od /I \".\" /I \"../include\" /I \"../include/modes\" /I \"../include/commands\" /I \"../win\" /D \"WIN32\" /D \"_DEBUG\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /Gm /EHsc /Gm /RTC1 /MTd /Fo\"Debug/\" /Fd\"Debug/vc70.pdb\" /W2 /Wp64 /Zi /TP $*.cpp ..\\win\\inspircd_memory_functions.cpp /link ..\\bin\\debug_x64\\bin\\inspircd.lib /OUT:\"..\\bin\\debug_x64\\lib\\$*.so\" /PDB:\"..\\bin\\debug_x64\\lib\\$*.pdb\" /MACHINE:X64 /IMPLIB:\"..\\bin\\debug_x64\\lib\\$*.lib\"\n\n");
+		fprintf(f, "  cl /nologo /LD /O1 /GL  /I \".\" /I \"../include\" /I \"../include/modes\" /I \"../include/commands\" /I \"../win\" /D \"WIN32\" /D \"_DEBUG\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /Gm /EHsc /Gm /MDd /Fo\"Debug/\" /Fd\"Debug/vc70.pdb\" /W2  /Zi /TP $*.cpp ..\\win\\inspircd_memory_functions.cpp /link ..\\bin\\debug_x64\\bin\\inspircd.lib /OUT:\"..\\bin\\debug_x64\\lib\\$*.so\" /PDB:\"..\\bin\\debug_x64\\lib\\$*.pdb\" /MACHINE:X64 /IMPLIB:\"..\\bin\\debug_x64\\lib\\$*.lib\"\n\n");
 		CreateDirectory("..\\bin\\debug", NULL);
 		CreateDirectory("..\\bin\\debug\\bin", NULL);
 		CreateDirectory("..\\bin\\debug\\lib", NULL);
 		CreateDirectory("..\\bin\\debug\\modules", NULL);
 	#else
-		fprintf(f, "  cl /nologo /LD /Od /I \".\" /I \"../include\" /I \"../include/modes\" /I \"../include/commands\" /I \"../win\" /D \"WIN32\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /EHsc /Gm /MT /Fo\"Release/\" /Fd\"Release/vc70.pdb\" /W2 /Wp64 /Zi /TP $*.cpp ..\\win\\inspircd_memory_functions.cpp /link ..\\bin\\release_x64\\bin\\inspircd.lib /OUT:\"..\\bin\\release_x64\\lib\\$*.so\" /PDB:\"..\\bin\\release_x64\\lib\\$*.pdb\" /MACHINE:X64 /IMPLIB:\"..\\bin\\release_x64\\lib\\$*.lib\"\n\n");
+		fprintf(f, "  cl /nologo /LD /O1 /GL  /I \".\" /I \"../include\" /I \"../include/modes\" /I \"../include/commands\" /I \"../win\" /D \"WIN32\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /EHsc /Gm /MD /Fo\"Release/\" /Fd\"Release/vc70.pdb\" /W2  /Zi /TP $*.cpp ..\\win\\inspircd_memory_functions.cpp /link ..\\bin\\release_x64\\bin\\inspircd.lib /OUT:\"..\\bin\\release_x64\\lib\\$*.so\" /PDB:\"..\\bin\\release_x64\\lib\\$*.pdb\" /MACHINE:X64 /IMPLIB:\"..\\bin\\release_x64\\lib\\$*.lib\"\n\n");
 		CreateDirectory("..\\bin\\release", NULL);
 		CreateDirectory("..\\bin\\release\\bin", NULL);
 		CreateDirectory("..\\bin\\release\\lib", NULL);
@@ -421,13 +422,13 @@ void WriteCompileCommands()
 	#endif
 #else
 	#ifdef _DEBUG
-		fprintf(f, "  cl /nologo /LD /Od /I \".\" /I \"../include\" /I \"../include/modes\" /I \"../include/commands\" /I \"../win\" /D \"WIN32\" /D \"_DEBUG\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /Gm /EHsc /Gm /RTC1 /MTd /Fo\"Debug/\" /Fd\"Debug/vc70.pdb\" /W2 /Wp64 /Zi /TP $*.cpp ..\\win\\inspircd_memory_functions.cpp /link ..\\bin\\debug\\bin\\inspircd.lib /OUT:\"..\\bin\\debug\\lib\\$*.so\" /PDB:\"..\\bin\\debug\\lib\\$*.pdb\" /IMPLIB:\"..\\bin\\debug\\lib\\$*.lib\"\n\n");
+		fprintf(f, "  cl /nologo /LD /O1 /GL  /I \".\" /I \"../include\" /I \"../include/modes\" /I \"../include/commands\" /I \"../win\" /D \"WIN32\" /D \"_DEBUG\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /Gm /EHsc /Gm /MDd /Fo\"Debug/\" /Fd\"Debug/vc70.pdb\" /W2  /Zi /TP $*.cpp ..\\win\\inspircd_memory_functions.cpp /link ..\\bin\\debug\\bin\\inspircd.lib /OUT:\"..\\bin\\debug\\lib\\$*.so\" /PDB:\"..\\bin\\debug\\lib\\$*.pdb\" /IMPLIB:\"..\\bin\\debug\\lib\\$*.lib\"\n\n");
 		CreateDirectory("..\\bin\\debug", NULL);
 		CreateDirectory("..\\bin\\debug\\bin", NULL);
 		CreateDirectory("..\\bin\\debug\\lib", NULL);
 		CreateDirectory("..\\bin\\debug\\modules", NULL);
 	#else
-		fprintf(f, "  cl /nologo /LD /Od /I \".\" /I \"../include\" /I \"../include/modes\" /I \"../include/commands\" /I \"../win\" /D \"WIN32\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /EHsc /Gm /MT /Fo\"Release/\" /Fd\"Release/vc70.pdb\" /W2 /Wp64 /Zi /TP $*.cpp ..\\win\\inspircd_memory_functions.cpp /link ..\\bin\\release\\bin\\inspircd.lib /OUT:\"..\\bin\\release\\lib\\$*.so\" /PDB:\"..\\bin\\release\\lib\\$*.pdb\" /IMPLIB:\"..\\bin\\release\\lib\\$*.lib\"\n\n");
+		fprintf(f, "  cl /nologo /LD /O1 /GL  /I \".\" /I \"../include\" /I \"../include/modes\" /I \"../include/commands\" /I \"../win\" /D \"WIN32\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /EHsc /Gm /MD /Fo\"Release/\" /Fd\"Release/vc70.pdb\" /W2  /Zi /TP $*.cpp ..\\win\\inspircd_memory_functions.cpp /link ..\\bin\\release\\bin\\inspircd.lib /OUT:\"..\\bin\\release\\lib\\$*.so\" /PDB:\"..\\bin\\release\\lib\\$*.pdb\" /IMPLIB:\"..\\bin\\release\\lib\\$*.lib\"\n\n");
 		CreateDirectory("..\\bin\\release", NULL);
 		CreateDirectory("..\\bin\\release\\bin", NULL);
 		CreateDirectory("..\\bin\\release\\lib", NULL);
@@ -484,18 +485,18 @@ void WriteCompileModules()
 #ifdef WIN64
 	// /MACHINE:X64
 	#ifdef _DEBUG
-		fprintf(f, "  cl /nologo /LD /Od /I \".\" /I \"../../include\" /I \"../../include/modes\" /I \"../../include/modules\" /I \"../../win\" /D \"WIN32\" /D \"_DEBUG\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /Gm /EHsc /Gm /RTC1 /MTd /Fo\"Debug/\" /Fd\"Debug/vc70.pdb\" /W2 /Wp64 /Zi /TP $*.cpp ..\\..\\win\\inspircd_memory_functions.cpp /link ..\\..\\bin\\debug_x64\\bin\\inspircd.lib ws2_32.lib /OUT:\"..\\..\\bin\\debug_x64\\modules\\$*.so\" /PDB:\"..\\..\\bin\\debug_x64\\modules\\$*.pdb\" /MACHINE:X64 /IMPLIB:\"..\\..\\bin\\debug_x64\\modules\\$*.lib\"\n\n");
+		fprintf(f, "  cl /nologo /LD /O1 /GL  /I \".\" /I \"../../include\" /I \"../../include/modes\" /I \"../../include/modules\" /I \"../../win\" /D \"WIN32\" /D \"_DEBUG\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /Gm /EHsc /Gm /MDd /Fo\"Debug/\" /Fd\"Debug/vc70.pdb\" /W2  /Zi /TP $*.cpp ..\\..\\win\\inspircd_memory_functions.cpp /link ..\\..\\bin\\debug_x64\\bin\\inspircd.lib ws2_32.lib /OUT:\"..\\..\\bin\\debug_x64\\modules\\$*.so\" /PDB:\"..\\..\\bin\\debug_x64\\modules\\$*.pdb\" /MACHINE:X64 /IMPLIB:\"..\\..\\bin\\debug_x64\\modules\\$*.lib\"\n\n");
 		CreateDirectory("..\\src\\modules\\debug_x64", NULL);
 	#else
-		fprintf(f, "  cl /nologo /LD /Od /I \".\" /I \"../../include\" /I \"../../include/modes\" /I \"../../include/modules\" /I \"../../win\" /D \"WIN32\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /EHsc /Gm /MT /Fo\"Release/\" /Fd\"Release/vc70.pdb\" /W2 /Wp64 /Zi /TP $*.cpp ..\\..\\win\\inspircd_memory_functions.cpp /link ..\\..\\bin\\release_x64\\bin\\inspircd.lib ws2_32.lib /OUT:\"..\\..\\bin\\release_x64\\modules\\$*.so\" /PDB:\"..\\..\\bin\\release_x64\\modules\\$*.pdb\" /MACHINE:X64 /IMPLIB:\"..\\..\\bin\\release_x64\\modules\\$*.lib\"\n\n");
+		fprintf(f, "  cl /nologo /LD /O1 /GL  /I \".\" /I \"../../include\" /I \"../../include/modes\" /I \"../../include/modules\" /I \"../../win\" /D \"WIN32\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /EHsc /Gm /MD /Fo\"Release/\" /Fd\"Release/vc70.pdb\" /W2  /Zi /TP $*.cpp ..\\..\\win\\inspircd_memory_functions.cpp /link ..\\..\\bin\\release_x64\\bin\\inspircd.lib ws2_32.lib /OUT:\"..\\..\\bin\\release_x64\\modules\\$*.so\" /PDB:\"..\\..\\bin\\release_x64\\modules\\$*.pdb\" /MACHINE:X64 /IMPLIB:\"..\\..\\bin\\release_x64\\modules\\$*.lib\"\n\n");
 		CreateDirectory("..\\src\\modules\\release_x64", NULL);
 	#endif
 #else
 	#ifdef _DEBUG
-		fprintf(f, "  cl /nologo -Dssize_t=long /LD /Od /I \".\" /I \"../../include\" /I \"../../include/modes\" /I \"../../include/modules\" /I \"../../win\" /D \"WIN32\" /D \"_DEBUG\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /Gm /EHsc /Gm /RTC1 /MTd /Fo\"Debug/\" /Fd\"Debug/vc70.pdb\" /W2 /Wp64 /Zi /TP $*.cpp ..\\..\\win\\inspircd_memory_functions.cpp /link ..\\..\\bin\\debug\\bin\\inspircd.lib ws2_32.lib /OUT:\"..\\..\\bin\\debug\\modules\\$*.so\" /PDB:\"..\\..\\bin\\debug\\modules\\$*.pdb\" /IMPLIB:\"..\\..\\bin\\debug\\modules\\$*.lib\"\n\n");
+		fprintf(f, "  cl /nologo -Dssize_t=long /LD /O1 /GL  /I \".\" /I \"../../include\" /I \"../../include/modes\" /I \"../../include/modules\" /I \"../../win\" /D \"WIN32\" /D \"_DEBUG\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /Gm /EHsc /Gm /MDd /Fo\"Debug/\" /Fd\"Debug/vc70.pdb\" /W2  /Zi /TP $*.cpp ..\\..\\win\\inspircd_memory_functions.cpp /link ..\\..\\bin\\debug\\bin\\inspircd.lib ws2_32.lib /OUT:\"..\\..\\bin\\debug\\modules\\$*.so\" /PDB:\"..\\..\\bin\\debug\\modules\\$*.pdb\" /IMPLIB:\"..\\..\\bin\\debug\\modules\\$*.lib\"\n\n");
 		CreateDirectory("..\\src\\modules\\debug", NULL);
 	#else
-		fprintf(f, "  cl /nologo -Dssize_t=long /LD /Od /I \".\" /I \"../../include\" /I \"../../include/modes\" /I \"../../include/modules\" /I \"../../win\" /D \"WIN32\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /EHsc /Gm /MT /Fo\"Release/\" /Fd\"Release/vc70.pdb\" /W2 /Wp64 /Zi /TP $*.cpp ..\\..\\win\\inspircd_memory_functions.cpp /link ..\\..\\bin\\release\\bin\\inspircd.lib ws2_32.lib /OUT:\"..\\..\\bin\\release\\modules\\$*.so\" /PDB:\"..\\..\\bin\\release\\modules\\$*.pdb\" /IMPLIB:\"..\\..\\bin\\release\\modules\\$*.lib\"\n\n");
+		fprintf(f, "  cl /nologo -Dssize_t=long /LD /O1 /GL  /I \".\" /I \"../../include\" /I \"../../include/modes\" /I \"../../include/modules\" /I \"../../win\" /D \"WIN32\" /D \"_CONSOLE\" /D \"_MBCS\" /D \"DLL_BUILD\" /EHsc /Gm /MD /Fo\"Release/\" /Fd\"Release/vc70.pdb\" /W2  /Zi /TP $*.cpp ..\\..\\win\\inspircd_memory_functions.cpp /link ..\\..\\bin\\release\\bin\\inspircd.lib ws2_32.lib /OUT:\"..\\..\\bin\\release\\modules\\$*.so\" /PDB:\"..\\..\\bin\\release\\modules\\$*.pdb\" /IMPLIB:\"..\\..\\bin\\release\\modules\\$*.lib\"\n\n");
 		CreateDirectory("..\\src\\modules\\release", NULL);
 	#endif
 #endif
